#' @title datasets with deprecated or defunct names
#'   
#' @description These are datasets that have been renamed but that have been
#'   temporarily retained for backward compatibility, or that have been renamed
#'   and the old names removed. Please change your code to use the new names, as
#'   the deprecated functions will become defunct in future versions.
#' @docType data
#' @name data-deprecated
#' @keywords internal deprecated
#' @format See the specific object documentation for the renamed objects.
NULL

#' @rdname data-deprecated
#' @name ukimmigTexts
#' @details \code{ukimmigTexts} is defunct; please use 
#'   \code{data_char_ukimmigration} instead.
NULL

#' @rdname data-deprecated
#' @name ie2010Corpus
#' @details \code{ie2010Corpus} is defunct; please use 
#'   \code{data_corpus_irishbudget2010} 
NULL

#' @rdname data-deprecated
#' @details \code{inaugTexts} is deprecated; please use
#'   \code{data_char_inaugural} instead.
"inaugTexts"

#' @rdname data-deprecated
#' @name data_char_inaugural
#' @details \code{data_char_inaugural} is defunct; please use
#'   \code{data_corpus_inaugural} instead.
NULL

#' @rdname data-deprecated
#' @name inaugCorpus
#' @details \code{inaugCorpus} is defunct; please use 
#'   \code{data_corpus_inaugural} instead.
NULL

#' @name LBGexample
#' @rdname data-deprecated
#' @details \code{LBGexample} is defunct; please use 
#'   \code{data_dfm_LBGexample} instead.
NULL

#' @name exampleString
#' @rdname data-deprecated
#' @details \code{exampleString} is defunct; please use 
#'   \code{data_char_sampletext} instead.
NULL

#' @name data_char_inaugural
#' @rdname data-deprecated
#' @details \code{data_char_inaugural} is defunct; please use
#'   \code{data_corpus_inaugural} instead.
NULL

#' @name data_char_mobydick
#' @rdname data-deprecated
#' @details \code{data_char_mobydick} is defunct; please use
#'   \code{data(mobydick, package = "tokenizers")} instead.
NULL




